<?php

    class in8_netsuite {

        public static $optionsTag = 'in8_tab_general';

        public static function getOptionsTag() {
            return self::$optionsTag;
        }

        function __construct() {

            // this will create the admin menu page
            add_action('admin_menu', [ $this, 'admin_menu']);
        }

        // this function will simply create the admin menu link inside the menu
        function admin_menu() {
            $page = add_menu_page("In8Sync", "In8Sync", "manage_options", "in8sync", [
                $this,
                'admin_page',
            ]);

            add_action('load-' . $page, array($this, 'in8_load_js_css'));
        }

        public function in8_load_js_css() {
            add_action('admin_enqueue_scripts', array($this, 'enqueue_admin_js'));
            add_action('admin_enqueue_scripts', array($this, 'enqueue_admin_css'));
        }

        public function enqueue_admin_js() {
            $js_dir = IN8_MAIN_URL . '/assets/js/';
            wp_enqueue_script('in8_admin_page_js', $js_dir . "admin_page.js");
            wp_enqueue_script('in8_admin_page_jquery_cookie', $js_dir . "jquery.cookie.js");
            wp_enqueue_script('in8_admin_page_enhanced_cookie', $js_dir . "jquery.enhanced.cookie.js");
            wp_enqueue_script('in8_admin_page_tip_min_js', $js_dir . "jquery.tipTip.minified.js");
            wp_localize_script('in8_admin_page_js', 'bsu', admin_url());
            wp_enqueue_script('in8_admin_page_jquery_dataTables_js', $js_dir . "jquery.dataTables.min.js");
            wp_enqueue_script('in8_admin_page_data_logs_js', $js_dir . "tabs.js");
	
            if( isset($_REQUEST['page']) && $_REQUEST['page'] == 'in8sync' ) {
				wp_enqueue_script('select2', 'https://cdnjs.cloudflare.com/ajax/libs/select2/4.0.5/js/select2.full.min.js', 'jquery');
			}
        }

        public function enqueue_admin_css() {
            $css_dir = IN8_MAIN_URL . '/assets/css/';
            wp_enqueue_style('in8_admin_page_css', $css_dir . "admin_page.css");
            wp_enqueue_style('in8_admin_page_tip_css', $css_dir . "tipTip.css");
            wp_enqueue_style('in8_admin_bootstrap_min_css', $css_dir . "bootstrap-theme.min.css");
            wp_enqueue_style('in8_admin_bootstrap_theme_min_css', $css_dir . "bootstrap.min.css");
            wp_enqueue_style('in8_admin_jquery_datatables_css', $css_dir . "jquery.dataTables.min.css");
	
			if( isset($_REQUEST['page']) && $_REQUEST['page'] == 'in8sync' ) {
				wp_enqueue_style( 'select2','https://cdnjs.cloudflare.com/ajax/libs/select2/4.0.5/css/select2.min.css' );
			}
        }

        // this function has the content of the admin page for this plugin
        function admin_page() {
            $tabs = in8_tabs::getAllTabs();
            ?>
            <div id="in8_page" class="parent">
                <div id="in8_menu">
                    <ul class="mainNav">
                        <?php foreach ($tabs as $tab_id => $tab) { ?>
                            <li data-for="<?php echo $tab_id; ?>" id="tab_<?php echo $tab_id; ?>" class="nav-tab"><?php echo $tab['label']; ?></li>
                        <?php } ?>
                    </ul>
                    <div class="clear"></div>
                </div>

                <div id="in8_pages">
                    <?php do_action('in8_netsuite_top_level_tabs_page'); ?>					
                </div>
            </div>

            <div id="in8_ajaxCall">Loading...</div>

            <?php
        }

    }

    $in8_netsuite = new in8_netsuite();
    