<?php

    class IN8_Settings {

        static $default_tabs = [
            'general' => ["label" => "General", "priority" => 0],
            'email' => ["label" => "Email Settings", "priority" => 80],
            'support' => ["label" => "Support", "priority" => 100],
            'logs' => ["label" => "Logs", "priority" => 90]
        ];
        //LOG DIRECTORY FOR VARIOUS RECORD TYPES
        public static $log_dirs = [
            'customer' => 'in8sync-customers',
            'customerforms' => 'in8sync-customers',
            'customer-search' => 'in8sync-customers',
            'customerforms' => 'in8sync-customers',
            'contact' => 'in8sync-customers',
            'salesorder' => 'in8sync-salesorder',
            'salesorder-customer' => 'in8sync-salesorder',
            'salesorder-customer-search' => 'in8sync-salesorder',
            'paymentmethod' => 'in8sync-salesorder',
            'shipitem' => 'in8sync-salesorder',
            'salesorderforms' => 'in8sync-salesorder',
            'purchaseorder' => 'in8sync-purchaseorder',
            'purchaseorder-vendor' => 'in8sync-purchaseorder',
            'purchaseorder-vendor-search' => 'in8sync-purchaseorder',
            'vendor' => 'in8sync-vendors',
            'product' => 'in8sync-products',
            'lead' => 'in8sync-leads',
            'map-locator' => 'in8-map-locator',
            'inventory' => 'in8sync-inventory'
        ];
        public static $debugging_modes = [
            '0' => 'No Logging',
            '1' => 'Normal error logging (File,Database & Email Logger)',
            '2' => 'Normal error logging plus save request json data',
            '3' => 'Show PHP errors/warnings'
        ];
        public static $ns_error_codes = [
            'INVALID_LOGIN_ATTEMPT',
            'INVALID_LOGIN_CREDENTIALS',
            'INVALID_REQUEST',
            'INVALID_RETURN_​DATA_​FORMAT',
            'SSS_INVALID_SCRIPTLET_ID',
            'SSS_INVALID_SRCH_COL',
            'UNEXPECTED_ERROR',
            'USER_ERROR',
            'RCRD_DSNT_EXIST',
            'REQUEST_PARAM_REQD',
            'RCRD_HAS_BEEN_CHANGED',
            'JS_EXCEPTION'
        ];
        public static $exportable_options = [
            'in8_tab_general' => 'Restlet Settings, Inventory Plugin Settings',
            'In8_Customer' => 'Customer Mapping',
            'in8_netsuite_products' => "Product Mapping",
            'in8_netsuite_inventory' => 'Inventory Settings',
            'In8_Customer_CM' => 'Customer Conditional Mapping',
            'In8_Customer_CO' => 'Customer Configurational Mapping',
            'In8_Lead' => 'Lead Mapping',
            'In8_Lead_CM' => 'Lead Conditional Mapping',
            'In8_Lead_CO' => 'Lead Configurational Mapping',
            'In8_Lead_Form' => 'Lead Registration Form',
            'In8_Vendor' => 'Vendor Mapping',
            'In8_Vendor_CM' => 'Vendor Conditional Mapping',
            'In8_Vendor_CO' => 'Vendor Configurational Mapping',
            'In8_SalesOrder' => 'SalesOrder Mapping',
            'In8_SalesOrder_CM' => 'SalesOrder Conditional Mapping',
            'In8_SalesOrder_CO' => 'SalesOrder Configurational Mapping',
            'In8_PurchaseOrder' => 'PurchaseOrder Mapping',
            'In8_PurchaseOrder_CM' => 'PurchaseOrder Conditional Mapping',
            'In8_PurchaseOrder_CO' => 'PurchaseOrder Configurational Mapping',
            'in8_tab_email' => 'Email Settings',
        ];

        public static function getTabSettings($tab_id, $block = '') {
            $debug_options = get_option($tab_id);
            if (!empty($debug_options)) {
                if (!empty($block) && isset($debug_options[$block]) && $debug_options[$block]) {
                    return $debug_options[$block];
                } else {
                    return $debug_options;
                }
            }
            return [];
        }

        public static function isSyncDisabled() {
	        $syncSettings = IN8_Settings::getTabSettings('in8_tab_general', 'ns_api_creds');
	        return isset($syncSettings['disable_sync']) && $syncSettings['disable_sync'] == 'on';
        }

        public static function saveTabSettings($tab_id, $block, $new_settings) {
            $old_options = get_option($tab_id);
            $new_options = [];
            if (!empty($old_options)) {
                $new_options = $old_options;
            }
            if(!empty($new_settings)) {
                $new_options[$block] = $new_settings;
            } else {
                $new_options[$block] = '';
            }
            update_option($tab_id, $new_options);
            return true;
        }

        public static function getDebuggingLevel() {
            $debug_options = self::getTabSettings('in8_tab_general', 'debug');
            if (isset($debug_options['debug_level'])) {
                $debug_mode = $debug_options['debug_level'];
            }

            if (!isset($debug_mode)) { //if not saved
                $debug_mode = 1;
            }
            return $debug_mode;
        }

        //EMAIL ACTIONS GET
        public static function getEmailActions() {
            $email_actions = self::getTabSettings('in8_tab_email', 'email_action');
            if ($email_actions !== FALSE) {
	            // VALIDATION
            	$email_actions['ns_error_code'] = !isset($email_actions['ns_error_code']) ? [] : $email_actions['ns_error_code'];
            	$email_actions['error_action'] = !isset($email_actions['error_action']) ? [] : $email_actions['error_action'];
            	$email_actions['error_action_emails'] = !isset($email_actions['error_action_emails']) ? [] : $email_actions['error_action_emails'];
            	
                $email_actions = array_combine($email_actions['ns_error_code'], array_map(null, $email_actions['error_action'], $email_actions['error_action_emails']));
            }

            return $email_actions;
        }

        public static function getLogFilePath($type = 'log', $object = '', $object_id = '') {
            $log_file_path = FALSE;
            if ($type == 'requestdata') {
                $file_ext = "json";
            } else {
                $file_ext = "log";
            }

            if (array_key_exists($object, self::$log_dirs)) {
                $plugin = self::$log_dirs[$object];
            } else {
                $plugin = 'in8sync';
            }

            //create directory name
            $file_sub_dir = $plugin . "/" . $object . '-' . $object_id . '.' . $file_ext;

            $wc_log_path = WP_CONTENT_DIR . "/uploads/wc-logs/";
            $log_file_full_path = $wc_log_path . $file_sub_dir;

            $log_file_full_dir = dirname($log_file_full_path);

            if (is_writable($wc_log_path)) {
                if (!file_exists($log_file_full_dir)) {
                    mkdir($log_file_full_dir, 0777, TRUE); //create dir recursively
                }
                $log_file_path = $log_file_full_path;
            }

            return $log_file_path;
        }

        public static function getLogFileURL($type = 'log', $object = '', $object_id = '') {
            if ($type == 'requestdata') {
                $file_ext = "json";
            } else {
                $file_ext = "log";
            }

            $log_file_url = FALSE;

            if (array_key_exists($object, self::$log_dirs)) {
                $plugin = self::$log_dirs[$object];
            } else {
                $plugin = 'in8sync';
            }

            $file_sub_dir = $plugin . "/" . $object . '-' . $object_id . '.' . $file_ext;
            $wc_log_path = WP_CONTENT_DIR . "/uploads/wc-logs/";

            $log_file_full_path = $wc_log_path . $file_sub_dir;

            if (file_exists($log_file_full_path)) {
                $log_file_url = WP_CONTENT_URL . "/uploads/wc-logs/" . $file_sub_dir;
            }

            return $log_file_url;
        }
	    
	    public static function deleteLogFiles($type = 'log', $object = '') {
		    if (array_key_exists($object, self::$log_dirs)) {
			
			    $plugin = self::$log_dirs[$object];
			    $sub_dir = $plugin . "/";
			    $request_data_file_path = WP_CONTENT_DIR . "/uploads/wc-logs/" . $sub_dir;
			
			    self::deletelog($request_data_file_path);
			    // WE only passed log directory path...
		    }
	    }
	
	    public static function deletelog($dir){
		
		    if (is_dir($dir)) {
			    $handle = opendir($dir);
			    if ($handle) {
				    while (false !== ($file = readdir($handle))) {
					
					    if (is_dir( "{$dir}/{$file}" )) { //If its directory then we called deletelog function recursively.
						    if (($file != '.') && ($file != '..')) {
							    //Deleting Files in the Directory: {$dir}/{$file}
							    self::deletelog("$dir/$file");
						    }
						    // the element is a file, so we delete it
					    } else {
						    $location = $dir . '/' . $file;
						    $location = str_replace('//', '/', $location);
						    $filelastmodified = filemtime($location);
						
						    //4*24 hours in a day * 3600 seconds per hour, 4 day old files found then we will delete that file
						    if ((time() - $filelastmodified) > 96 * 3600) {
							    unlink( $location );
						    }
					    }
				    }
				    closedir($handle);
			    }
		    }
	    }

    }
    